# Tracé d'un graphe donnant le pourcentage de prédominance des formes pour un diacide
import matplotlib.pyplot as plt
import numpy as np
import matplotlib.ticker as mtick#Format pourcentage

#Paramètres à personnaliser-----------------------------
pKa1=5
pKa2=8
pHmin=0
pHmax=14
#autre option de réglage :
#pHmin=pKa1-2
#pHmax=pKa2+2

fig, ax=plt.subplots()
pH=np.arange(pHmin, pHmax, 0.1)

#D'après la formule pH=pKa + log [base]/[acide] :
acide=100/(1+10**(pH-pKa1))
base=100*10**(pH-pKa2)/(1+10**(pH-pKa2))
amph=100-acide-base

plt.plot(pH, acide, label='forme acide')
plt.plot(pH, base, label='forme basique')
plt.plot(pH, amph, label='amphotère')
plt.legend(loc='right')
plt.xlabel('pH')
plt.title(r"Prédominance des formes acidobasiques pour un diacide")

#Réglages des espaces de graduations des axes :
plt.yticks(np.arange(0, 100, 10))
#plt.xticks(np.arange(0, 14, 1))
ax.yaxis.set_major_formatter(mtick.PercentFormatter(symbol= ' %'))

#réglage perso de la grille secondaire :
minor_xticks = np.arange(0, 14, 1)#grille secondaire en x
minor_yticks = np.arange(0, 101, 5)#grille secondaire en y
ax.set_xticks(minor_xticks, minor=True)
ax.set_yticks(minor_yticks, minor=True)

plt.axis([pHmin, pHmax, 0, 105])#limites des axes

#traits de lecture du pKa-------------------------------------------------------------------
plt.plot([pHmin, pKa2], [50, 50], 'r--')
plt.plot([pKa1, pKa1], [50, 0], 'r--')
plt.plot([pKa2, pKa2], [50, 0], 'r--')
plt.text(pHmin+0.5, 30, r'$pKa_1=$ %s' %(pKa1), backgroundcolor='white', color='red',  fontsize=14)
plt.text(pHmin+0.5, 20, r'$pKa_2=$ %s' %(pKa2), backgroundcolor='white', color='red',  fontsize=14)

plt.grid()
plt.show()
